import { FFmpegCommandWrapper } from './ffmpeg-command-wrapper.js';
import { getVideoStreamDuration } from './ffprobe.js';
export class FFmpegImage {
    constructor(options) {
        this.commandWrapper = new FFmpegCommandWrapper(options);
    }
    convertWebPToJPG(options) {
        const { path, destination } = options;
        this.commandWrapper.buildCommand(path)
            .output(destination);
        return this.commandWrapper.runCommand({ silent: true });
    }
    processGIF(options) {
        const { path, destination, newSize } = options;
        this.commandWrapper.buildCommand(path)
            .fps(20)
            .size(`${newSize.width}x${newSize.height}`)
            .output(destination);
        return this.commandWrapper.runCommand();
    }
    async generateThumbnailFromVideo(options) {
        const { fromPath, output, ffprobe, framesToAnalyze } = options;
        let duration = await getVideoStreamDuration(fromPath, ffprobe);
        if (isNaN(duration))
            duration = 0;
        this.commandWrapper.buildCommand(fromPath)
            .seekInput(duration / 2)
            .videoFilter('thumbnail=' + framesToAnalyze)
            .outputOption('-frames:v 1')
            .output(output);
        return this.commandWrapper.runCommand();
    }
    async generateStoryboardFromVideo(options) {
        const { path, destination, sprites } = options;
        const command = this.commandWrapper.buildCommand(path);
        const filter = [
            `setpts=N/round(FRAME_RATE)/TB`,
            `select='not(mod(t,${options.sprites.duration}))'`,
            `scale=${sprites.size.width}:${sprites.size.height}`,
            `tile=layout=${sprites.count.width}x${sprites.count.height}`
        ].join(',');
        command.outputOption('-filter_complex', filter);
        command.outputOption('-frames:v', '1');
        command.outputOption('-q:v', '2');
        command.output(destination);
        return this.commandWrapper.runCommand();
    }
}
//# sourceMappingURL=ffmpeg-images.js.map